@@ -146,7 +146,7 @@ let rec print_exn ppf = function
       Format.fprintf ppf "Source filename must have extension .cd@.";
   | InvalidObjectFilename f ->
       Format.fprintf ppf "Compilation error:@.";
-      Format.fprintf ppf "Object filename must have extension .cdo and no path@.";
+      Format.fprintf ppf "Object filename must have extension .cdo@.";
   | Librarian.InvalidObject f ->
       Format.fprintf ppf "Invalid object file %s@." f
   | Librarian.CannotOpen f ->
@@ -347,15 +347,15 @@ let compile_run src =
   with exn -> catch_exn Format.err_formatter exn; exit 1
 
 let run obj =  
+ Cduce_loc.obj_path := (Filename.dirname obj)::!Cduce_loc.obj_path ;
+ let obj = Filename.basename obj in
   try
-    if not (Filename.check_suffix obj ".cdo") || (Filename.basename obj <> obj)
-    then raise (InvalidObjectFilename obj);
+    if not (Filename.check_suffix obj ".cdo") then raise (InvalidObjectFilename obj);
     let name = Filename.chop_suffix (Filename.basename obj) ".cdo" in
     let name = U.mk_latin1 name in
     Librarian.load_run name
   with exn -> catch_exn Format.err_formatter exn; exit 1
 
-
 let dump_env ppf = dump_env ppf !typing_env !compile_env
 
 let eval s =
