@@ -1305,8 +1305,7 @@ let bib : Biblio =
 let titles = [bib]/<paper>_/<title>_
 let authors = [bib]/<paper>_/<author>_
 let titles_concat = [bib]/<paper>_/<title>_/Char
-";"xtransform","
-(* For the purpose of the example we can consider this hugely
+";"xtransform","(* For the purpose of the example we can consider this hugely
    simplified definition of Xhtml
 *)
 
@@ -1332,7 +1331,7 @@ type Address = <address>[ Inline* ];;
 type Pre = <pre>[ (PCDATA | A | Fontstyle)* ];;
 type Center = <center>[ Block* ];;
 
-type A = <a ({ name = String } | { href = String })>[ (Inline \ A)* ];;
+type A = <a ({ name = String } | { href = String })>[ (Inline)* ];;
 type Tt = <tt>[ Inline* ];;
 type I = <i>[ Inline* ];;
 type B = <b>[ Inline* ];;
@@ -1348,7 +1347,7 @@ type Small = <small>[ Inline* ];;
    document as follows
 *)
 
-let bold(x:[Xhtml]):[Xhtml]=xtransform x with <a (y)>t -> [ <a(y)>[<b>t] ]
+let bold (x:[Xhtml]):[Xhtml] = xtransform x with <a (y)>t -> [ <a (y)>[<b>t] ]
 
 
 (* let us apply the function to a document where links appear
@@ -1377,7 +1376,7 @@ let doc : Xhtml =
           <a href=\"xtransform\">[<tt>\"xtransform\"] 
           ' will put all links in bold so that when'
           ' you program your transformation you '
-          <big>[<a name=\"\">\" don\'t \" ] ' have to worry about it'
+          <big>[<a name=\"\">\" don't \" ] ' have to worry about it'
      ]
    ]
   ];;
