@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 open Ident
@@ -21,7 +21,7 @@ let version () =
   Printf.eprintf "built on %s\n" <:symbol<build_date>>;
   Printf.eprintf "using OCaml %s compiler\n" <:symbol<ocaml_compiler>>;
   Printf.eprintf "Supported features: \n";
-  List.iter (fun (n,d) -> Printf.eprintf "- %s: %s\n" n d) (Config.descrs ());
+  List.iter (fun (n,d) -> Printf.eprintf "- %s: %s\n" n d) (Cduce_config.descrs ());
   exit 0
 
 let specs =
@@ -35,7 +35,7 @@ let specs =
              "(for --compile) show types of exported values";
     "--obj-dir",  Arg.String (fun s -> out_dir := s :: !out_dir),
              "(for --compile) directory for the compiled .cdo file";
-    "-I", Arg.String (fun s -> Location.obj_path := s::!Location.obj_path),
+    "-I", Arg.String (fun s -> Cduce_loc.obj_path := s::!Cduce_loc.obj_path),
       "       add one directory to the lookup path for .cdo/.cmi and include files";
     "--stdin", Arg.Unit (fun () -> src := "" :: !src),
            "  read CDuce script on standard input";
@@ -46,7 +46,7 @@ let specs =
 						src := s :: !src)
 			    else args := s :: !args),
             " the first argument after is the source, then the arguments";
-    "--no", Arg.String Config.inhibit,
+    "--no", Arg.String Cduce_config.inhibit,
         "     disable a feature (cduce -v to get a list of features)";
     "--debug", Arg.Unit (fun () -> Stats.set_verbosity Stats.Summary),
            "  print profiling/debugging information";
@@ -130,7 +130,7 @@ let toploop () =
   Cduce.toplevel := true;
   Librarian.run_loaded := true;
   let buf_in = Buffer.create 1024 in
-  Location.push_source (`Buffer buf_in);
+  Cduce_loc.push_source (`Buffer buf_in);
   let read _i =
     if !bol then 
       if !Ulexer.in_comment then outflush "* " else outflush "> ";
@@ -157,26 +157,26 @@ let argv args =
 
 let main () = 
   at_exit (fun () -> Stats.dump Format.std_formatter);
-  Location.set_viewport (Html.create false);
+  Cduce_loc.set_viewport (Html.create false);
   match mode () with
     | `Toplevel args ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	Builtin.argv := argv args;
 	toploop ()
     | `Script (f,args) ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	Builtin.argv := argv args;
 	Cduce.compile_run f
     | `Compile (f,o) ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	Cduce.compile f o
     | `Run (f,args) ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	Builtin.argv := argv args;
 	Cduce.run f
     | `Mlstub f ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	Librarian.prepare_stub f
     | `Topstub f ->
-	Config.init_all ();
+	Cduce_config.init_all ();
 	!Librarian.make_wrapper f
