@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 (* TODO:
@@ -135,11 +135,11 @@ let main (cgi : Netcgi.std_activation) =
     let dialog content = html_form p content in
 
     let exec src =
-      let v = Location.get_viewport () in
+      let v = Cduce_loc.get_viewport () in
       let ppf = Html.ppf v
       and input = Stream.of_string src in
-      Location.push_source (`String src);
-      Location.set_protected true;
+      Cduce_loc.push_source (`String src);
+      Cduce_loc.set_protected true;
       
       let ok = Cduce.script ppf ppf input in
       if ok then Format.fprintf ppf "@\nOk.@\n";
@@ -150,7 +150,7 @@ let main (cgi : Netcgi.std_activation) =
       dialog src
     in
 
-    Location.set_viewport (Html.create true);
+    Cduce_loc.set_viewport (Html.create true);
     html_header p;
     let prog = cgi # argument_value "prog" in
     (match cmd with
