@@ -169,14 +169,14 @@ let rec unfold_constr env p args =
 
       slot.def <- 
 	(match decl.type_kind, decl.type_manifest with
-	   | Type_variant (cstrs,pub), _ ->
+	   | Type_variant (cstrs), _ ->
 	       let cstrs =
 		 List.map 
 		   (fun (cst,f) -> (cst,List.map (unfold env) f)) cstrs in
-	       Variant (prefix, cstrs, pub = Caml_cduce.Asttypes.Public)
-	   | Type_record (f,_,pub), _ ->
+	       Variant (prefix, cstrs, true)
+	   | Type_record (f,_), _ ->
 	       let f = List.map (fun (l,_,t) -> (l,unfold env t)) f in
-	       Record (prefix, f, pub = Caml_cduce.Asttypes.Public)
+	       Record (prefix, f, true)
 	   | Type_abstract, Some t ->
 	       Link (unfold env t)
 	   | Type_abstract, None ->
