@@ -1,12 +1,12 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 (*  Abstract syntax as produced by the parser *)
 
-open Location
+open Cduce_loc
 open Ident
 
 type ns_expr = [ `Uri of Ns.Uri.t | `Path of U.t list ]
@@ -15,7 +15,7 @@ type pprog = pmodule_item list
 
 and pmodule_item = pmodule_item' located
 and pmodule_item' =
-  | TypeDecl of (Location.loc * U.t) * ppat
+  | TypeDecl of (Cduce_loc.loc * U.t) * ppat
   | SchemaDecl of U.t * string
   | LetDecl of ppat * pexpr
   | FunDecl of pexpr
@@ -92,7 +92,7 @@ and pexpr =
 and label = U.t
 
 and abstr = { 
-  fun_name : (Location.loc * U.t) option; 
+  fun_name : (Cduce_loc.loc * U.t) option; 
   fun_iface : (ppat * ppat) list;
   fun_body : branches
 }
@@ -106,7 +106,7 @@ and ppat' =
   | PatVar of U.t list
   | Cst of pexpr
   | NsT of U.t
-  | Recurs of ppat * (Location.loc * U.t * ppat) list
+  | Recurs of ppat * (Cduce_loc.loc * U.t * ppat) list
   | Internal of Types.descr
   | Or of ppat * ppat
   | And of ppat * ppat
@@ -129,7 +129,7 @@ and regexp =
   | Alt of regexp * regexp
   | Star of regexp
   | WeakStar of regexp
-  | SeqCapture of Location.loc * U.t * regexp
+  | SeqCapture of Cduce_loc.loc * U.t * regexp
 
 
 let pat_true = mknoloc (Internal Builtin_defs.true_type)
