@@ -9,7 +9,14 @@ let load_url s =
     let buff = Buffer.create 4096 in 
     let conn = Curl.init () in
     Curl.set_url conn s;
-    Curl.set_writefunction conn (Buffer.add_string buff);
+    Curl.set_writefunction conn (
+      fun str ->
+	try
+          Buffer.add_string buff str;
+	  String.length str
+	with
+	    Failure _ -> 0
+      );
     Curl.perform conn;
     Buffer.contents buff
   with Curl.CurlException (code, n, msg) ->
