@@ -1,31 +1,33 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 #load "pa_extend.cmo";;
 
-open Location
+open Cduce_loc
+(* let raise = Pervasives.raise *)
 open Ast
 open Ident
 open Printf
+open Ulexer
 
 (*
 let ()  = Grammar.error_verbose := true
 *)
 
-let tloc (i,j) = (i.Lexing.pos_cnum,j.Lexing.pos_cnum)
-let nopos = (Lexing.dummy_pos, Lexing.dummy_pos)
+let tloc (i,j) = (i,j)
+let nopos = (-1,-1)
 
 
-let mk loc x = Location.mk (tloc loc) x
+let mk loc x = Cduce_loc.mk_located (tloc loc) x
 
 exception Error of string
-let error (i,j) s = Location.raise_loc i j (Error s)
+let error (i,j) s = Cduce_loc.raise_loc i j (Error s)
 let error loc s = error (tloc loc) s
 
-let gram    = Grammar.gcreate Ulexer.lex
+module Gram = Camlp4.Struct.Grammar.Static.Make(Ulexer)
 
 let id_dummy = U.mk "$$$"
 
@@ -42,14 +44,14 @@ let ident s =
 let label s = U.mk (ident s)
 let ident s = U.mk (ident s)
 
-let prog    = Grammar.Entry.create gram "prog"
-let top_phrases   = Grammar.Entry.create gram "toplevel phrases"
-let expr    = Grammar.Entry.create gram "expression"
-let pat     = Grammar.Entry.create gram "type/pattern expression"
-let regexp  = Grammar.Entry.create gram "type/pattern regexp"
-let keyword = Grammar.Entry.create gram "keyword"
+let prog    = Gram.Entry.mk "prog"
+let top_phrases   = Gram.Entry.mk "toplevel phrases"
+let expr    = Gram.Entry.mk "expression"
+let pat     = Gram.Entry.mk "type/pattern expression"
+let regexp  = Gram.Entry.mk "type/pattern regexp"
+let keyword = Gram.Entry.mk "keyword"
 		
-let lop pos = loc_of_pos (tloc pos)
+let lop pos = Cduce_loc.loc_of_pos (tloc pos)
 let exp pos e = LocatedExpr (lop pos,e)
 
 let rec multi_prod loc = function
@@ -92,24 +94,26 @@ let protect_exn f g =
 let localize_exn f = 
   try f ()
   with
-  | Stdpp.Exc_located (_, (Location _ as e)) -> raise e
-(*  | Stdpp.Exc_located ((i,j), e) -> raise_loc i j e *)
-  | Stdpp.Exc_located ((i,j), e) -> raise_loc i.Lexing.pos_cnum j.Lexing.pos_cnum e
+  | Ulexer.Loc.Exc_located (_, (Location _ as e)) -> raise e
+(*  | Camlp4.PreCast.Loc.Exc_located ((i,j), e) -> raise_loc i j e *)
+  | Ulexer.Loc.Exc_located (loc, e) ->
+      let i, j = Ulexer.Loc.start_off loc, Ulexer.Loc.stop_off loc in
+      raise_loc i j e
 
 let is_fun_decl =
-   Grammar.Entry.of_parser gram "[is_fun_decl]"
+   Gram.Entry.of_parser "[is_fun_decl]"
      (fun strm ->
        match Stream.npeek 3 strm with
-	 | [ ("", "fun"); ("IDENT", _); ("", "(") ]
-	 | [ ("IDENT", _) ; ("", "(") ; _ ] -> ()
+	 | [ KEYWORD "fun", _; IDENT _, _; KEYWORD "(", _ ]
+	 | [ IDENT _, _; KEYWORD "(", _; _ ] -> ()
 	 | _ -> raise Stream.Failure
      )
 
 let is_capture =
-   Grammar.Entry.of_parser gram "[is_capture]"
+   Gram.Entry.of_parser "[is_capture]"
      (fun strm ->
        match Stream.npeek 2 strm with
-	 | [ ("IDENT", _) ; ("", "::") ; _ ] -> ()
+	 | [ IDENT _, _; KEYWORD "::", _; _ ] -> ()
 	 | _ -> raise Stream.Failure
      )
 
@@ -129,7 +133,7 @@ let let_in e1 p e2 =  Match (e1, [p,e2])
 let seq e1 e2 = let_in e1 pat_nil e2
 let concat e1 e2 = apply_op2_noloc "@" e1 e2
 
-EXTEND
+EXTEND Gram
   GLOBAL: top_phrases prog expr pat regexp keyword;
 
   top_phrases: [
@@ -137,7 +141,7 @@ EXTEND
   ];
 
   prog: [
-    [ l = LIST0 [ p = phrase ; OPT ";;" -> p ]; EOI -> List.flatten l ]
+    [ l = LIST0 [ p = phrase ; OPT ";;" -> p ]; `EOI -> List.flatten l ]
   ];
 
   phrase: [
@@ -147,9 +151,9 @@ EXTEND
     | (_,p,e1) = let_binding; "in"; e2 = expr LEVEL "top"->
         [ mk _loc (EvalStatement (exp _loc (let_in e1 p e2))) ]
     | "type"; x = located_ident; "="; t = pat -> [ mk _loc (TypeDecl (x,t)) ]
-    | "using"; name = IDENT; "="; cu = [ IDENT | STRING2 ] ->
+    | "using"; name = IDENT; "="; cu = [ x = IDENT -> x | x = STRING2 -> x ] ->
 	[ mk _loc (Using (U.mk name, U.mk cu)) ]
-    | "open"; ids = LIST1 [ IDENT | keyword ] SEP "." -> 	  
+    | "open"; ids = LIST1 ident_or_keyword SEP "." ->
 	let ids = List.map (fun x -> ident x) ids in
 	[ mk _loc (Open ids) ]
     | "schema"; name = IDENT; "="; uri = STRING2 ->
@@ -183,14 +187,14 @@ EXTEND
     | "#"; IDENT "builtins" -> [ mk _loc (Directive `Builtins) ]
     | "include"; s = STRING2 ->
 	protect_op "File inclusion";
-	let s = Location.resolve_filename s in
+	let s = Cduce_loc.resolve_filename s in
 	(* avoid looping; should issue an error ? *)
 	(* it is possible to have looping with x/../x/../x/.. ....
 	   Need to canonicalize filename *)
 	if List.mem s !include_stack then [] 
 	else (
 	  include_stack := s :: !include_stack;
-	  Location.push_source (`File s);
+	  Cduce_loc.push_source (`File s);
 	  let saved_enc = !Ulexer.enc in
 	  Ulexer.enc := Ulexing.Latin1;
 	  protect_exn
@@ -199,11 +203,11 @@ EXTEND
 	       protect_exn
 		 (fun () ->
 		    let input = Stream.of_channel chan in
-		    localize_exn (fun () -> Grammar.Entry.parse prog input))
+		    localize_exn (fun () -> Gram.parse prog Ulexer.Loc.ghost input))
 		 (fun () -> close_in chan))
 	    (fun () ->
 	       Ulexer.enc := saved_enc;
-	       Location.pop_source ();
+	       Cduce_loc.pop_source ();
 	       include_stack := List.tl !include_stack)
 	)
     ] | 
@@ -234,6 +238,11 @@ EXTEND
     ]
   ];
 
+  ident_or_keyword: [
+    [ s = IDENT -> s
+    | s = keyword -> s ]
+  ];
+
   expr: [
     "top" RIGHTA
     [ "match"; e = SELF; "with"; b = branches -> 
@@ -287,7 +296,7 @@ EXTEND
     | 
     [ e1 = expr; op = ["+" | "-" | "@" ]; e2 = expr -> apply_op2 _loc op e1 e2
     | e1 = expr; ["||" | "or"]; e2 = expr -> exp _loc (logical_or e1 e2)
-    | e = expr; "\\"; l = [IDENT | keyword ] -> 
+    | e = expr; "\\"; l = ident_or_keyword -> 
 	exp _loc (RemoveField (e, label l)) 
     ]
     |
@@ -302,7 +311,7 @@ EXTEND
 	let ct = mk _loc (Regexp re) in
         let p = mk _loc (XmlT (tag, multi_prod _loc [att;ct])) in
 	exp _loc (Transform (e,[p, Var id_dummy]))
-    | e = expr; "/@"; a = [IDENT|keyword] ->
+    | e = expr; "/@"; a = ident_or_keyword ->
 	(* transform e with <(Atom) {a=$$$}>_ -> [$$$] *)
         let tag = mk _loc (Internal (Types.atom Atoms.any)) in
         let any = mk _loc (Internal Types.any) in
@@ -356,7 +365,7 @@ EXTEND
 
     | "no_appl" 
 
-    [ e = expr;  "."; l = [IDENT | keyword ]; 
+    [ e = expr;  "."; l = ident_or_keyword; 
       tyargs = [ "with"; "{"; tyargs = LIST0 pat; "}" -> Some tyargs
       | -> None ] ->
 	let e = Dot (e,label l) in
@@ -397,11 +406,11 @@ EXTEND
 
   ];
 
-  tag: [ [ a = [ IDENT | keyword ] -> exp _loc (Atom (ident a)) ] ];
+  tag: [ [ a = ident_or_keyword -> exp _loc (Atom (ident a)) ] ];
 
   tag_type: [
     [ "_" ->  mk _loc (Internal (Types.atom Atoms.any))
-    | a = [ IDENT | keyword ] -> mk _loc (Cst (Atom (ident a)))
+    | a = ident_or_keyword -> mk _loc (Cst (Atom (ident a)))
     | t = ANY_IN_NS -> mk _loc (NsT (ident t)) 
     ]
   ];
@@ -418,7 +427,7 @@ EXTEND
   namespace_binding: [
     [ "namespace"; r = [
 	[ name = 
-	    [ name = [ IDENT | keyword ]; "=" -> ident name
+	    [ name = ident_or_keyword; "=" -> ident name
 	    | -> U.mk "" ];
 	  ns = ns_expr -> `Prefix (name,ns)
 	| IDENT "on" -> `Keep true
@@ -428,7 +437,7 @@ EXTEND
 
   ns_expr: [
     [ uri = STRING2 -> `Uri (Ns.Uri.mk (ident uri))
-    | ids = LIST1 [ IDENT | keyword ] SEP "." -> 	  
+    | ids = LIST1 ident_or_keyword SEP "." -> 	  
 	let ids = List.map (fun x -> ident x) ids in
 	`Path ids ]
   ];
@@ -579,11 +588,11 @@ EXTEND
   ];
 
   schema_ref: [
-    [ schema = IDENT; "."; typ = [ IDENT | keyword ] -> (U.mk schema, ident typ)
+    [ schema = IDENT; "."; typ = ident_or_keyword -> (U.mk schema, ident typ)
     ]
   ];
 
-  located_ident: [ [ a = [IDENT|keyword] -> (lop _loc,ident a) ] ];
+  located_ident: [ [ a = ident_or_keyword -> (lop _loc,ident a) ] ];
 
   pat: [ 
       [ x = pat; "where"; 
@@ -609,7 +618,7 @@ EXTEND
 	  mk _loc (Constant (ident a,c))
       | "!"; a = IDENT ->
 	  mk _loc (Internal (Types.abstract (Types.Abstract.atom a)))
-      | ids = LIST1 [ IDENT | keyword ] SEP "." ->
+      | ids = LIST1 ident_or_keyword SEP "." ->
 	  let ids = List.map (fun x -> ident x) ids in
 	  mk _loc (PatVar ids)
       | i = INT ; "--"; j = INT -> 
@@ -669,7 +678,7 @@ EXTEND
                   x = pat;  y = or_else -> (o,x,y) ] ] ];
 
   record_spec:
-    [ [ r = LIST0 [ l = [IDENT | keyword ]; f = opt_field_pat; OPT ";" ->
+    [ [ r = LIST0 [ l = ident_or_keyword; f = opt_field_pat; OPT ";" ->
 		      let (o,x,y) =
 			match f with
 			  | None -> (false, mknoloc (PatVar [ident l]), None)
@@ -696,7 +705,7 @@ EXTEND
 
   expr_record_spec:
     [ [ r = LIST0
-	      [ l = [IDENT | keyword ]; 
+	      [ l = ident_or_keyword; 
 		x = opt_field_expr; OPT ";" ->
 		  let x = match x with Some x -> x | None ->  Var (ident l) in
 		  (label l,x) ] 
@@ -716,23 +725,16 @@ module Hook = struct
   let keyword = keyword
 end
 
-let pat = Grammar.Entry.parse pat
-and expr = Grammar.Entry.parse expr
-and prog = Grammar.Entry.parse prog
-and top_phrases = Grammar.Entry.parse top_phrases
+let pat = Gram.parse pat Ulexer.Loc.ghost
+and expr = Gram.parse expr Ulexer.Loc.ghost
+and prog = Gram.parse prog Ulexer.Loc.ghost
+and top_phrases = Gram.parse top_phrases Ulexer.Loc.ghost
 
 let sync () = 
   match !Ulexer.lexbuf with
     | None -> ()
     | Some lb ->
-	let rec aux () =
-	  match !Ulexer.last_tok with
-	    | ("",";;") | ("EOI","") -> ()
-	    | _ -> 
-		Ulexer.last_tok := fst (Ulexer.token lb); 
-		aux ()
-	in
-	aux ()
+        Ulexer.sync lb
 
 let sync () =
   try sync ()
