@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 exception Error of string
@@ -14,12 +14,14 @@ val top_phrases : char Stream.t -> Ast.pmodule_item list
 val sync : unit -> unit
 val localize_exn: (unit -> 'a) -> 'a
 
+module Gram : Camlp4.Sig.Grammar.Static
+
 (* Hooks to extend the syntax *)
 
 module Hook: sig
-  val expr: Ast.pexpr Grammar.Entry.e
-  val pat: Ast.ppat Grammar.Entry.e
-  val keyword: string Grammar.Entry.e
+  val expr: Ast.pexpr Gram.Entry.t
+  val pat: Ast.ppat Gram.Entry.t
+  val keyword: string Gram.Entry.t
 end
 
 (* Helpers *)
