@@ -12,7 +12,14 @@ let start_with s p =
   else None
 
 let is_url s = 
-  try let _ = Neturl.extract_url_scheme s in true
+  try
+    match Sys.os_type with
+      | "Cygwin" | "Win32" ->
+        let uscheme = Neturl.extract_url_scheme s in
+        if String.length uscheme == 1
+        then false
+        else true
+      | _ -> let _ = Neturl.extract_url_scheme s in true
   with Neturl.Malformed_URL -> false
 	
 let no_load_url s =
