@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 let buflen = 1024
@@ -59,7 +59,7 @@ let use () = Load_xml.xml_parser :=
     Load_xml.text_handler
 
 let () = 
-  Config.register 
+  Cduce_config.register 
     "expat" 
     "Expat XML parser"
     use
