@@ -72,9 +72,13 @@ let false_literal = U.mk "false"
 
   (* @raise exn_print_xml in case of failure. Rationale: schema printing is
    * the last attempt to print a value, others have already failed *)
-let rec schema_value ?(recurs=true) ~wds v = match v with
-  | Abstract ("float",f) ->
-      wds (U.mk (string_of_float (Obj.magic f : float)))
+let rec schema_value ?(recurs=true) ~wds ~wcs v = match v with
+  | Abstract ("float",o) ->
+      wds (U.mk (string_of_float (Obj.magic o : float)))
+  | Abstract ("cdata",o) ->
+      wcs (U.mk "<![CDATA[");
+      wcs (U.mk (U.get_str (Obj.magic o : U.t)));
+      wcs (U.mk "]]>")
   | Record _ as v ->
       (try
         wds (Schema_builtin.string_of_time_type (Value.get_fields v))
@@ -82,18 +86,18 @@ let rec schema_value ?(recurs=true) ~wds v = match v with
   | Integer i -> wds (U.mk (Intervals.V.to_string i))
   | v when Value.equal v Value.vtrue -> wds true_literal
   | v when Value.equal v Value.vfalse -> wds false_literal
-  | Pair _ as v when recurs -> schema_values ~wds v
+  | Pair _ as v when recurs -> schema_values ~wds ~wcs v
   | String_utf8 _ | String_latin1 _ as v -> wds (fst (get_string_utf8 v))
   | _ -> raise exn_print_xml
 
-and schema_values ~wds v =
+and schema_values ~wds ~wcs v =
   match v with
   | Pair (hd, Atom a) when a = Sequence.nil_atom ->
-      schema_value ~recurs:false ~wds hd
+      schema_value ~recurs:false ~wds ~wcs hd
   | Pair (hd, tl) ->
-      schema_value ~recurs:false ~wds hd;
+      schema_value ~recurs:false ~wds ~wcs hd;
       wds blank;
-      schema_values ~wds tl
+      schema_values ~wds ~wcs tl
   | _ -> raise exn_print_xml
 
 let to_buf ~utf8 buffer ns_table v = 
@@ -103,7 +107,7 @@ let to_buf ~utf8 buffer ns_table v =
 
   let wms = write_markup_string ~to_enc buffer
   and wds s = write_data_string ~to_enc buffer (U.get_str s)
-  in
+  and wcs s = buffer (U.get_str s) in
   let write_att (n,v) =
     wms (" " ^ (Ns.Printer.attr printer (Label.value n)) ^ "=\""); wds v; wms "\"" in
   let write_xmlns (pr,ns) =
@@ -166,7 +170,7 @@ let to_buf ~utf8 buffer ns_table v =
                          end else begin
                            let buf = Buffer.create 20 in
                            let wds s = Buffer.add_string buf (U.get_str s) in
-                           schema_value ~wds v;
+                           schema_value ~wds ~wcs:wds v;
                            (Label.from_int n, U.mk (Buffer.contents buf))
                          end
 		      ) attrs in
@@ -183,7 +187,7 @@ let to_buf ~utf8 buffer ns_table v =
     match q with
       | Pair ((Xml _ | XmlNs _) as x, q) -> print_elt [] x; print_content q
       | Atom a when a = Sequence.nil_atom -> ()
-      | v -> schema_value ~wds v
+      | v -> schema_value ~wds ~wcs v
   in
   document_start ();
   print_elt (Ns.Printer.prefixes printer) v
