@@ -290,6 +290,11 @@ let rec print ppf v =
 	Format.fprintf ppf "<concat:%a;%a>" print x print y
     | Abstract ("float",o) ->
 	Format.fprintf ppf "%f" (Obj.magic o : float)
+    | Abstract ("cdata",o) ->
+        let s = Utf8.get_str (Obj.magic o : Utf8.t) in
+        Format.fprintf ppf "'%s'" s
+        (* Format.fprintf ppf "%s" (Utf8.get_str (Obj.magic o :
+            * Encodings.Utf8.t)) *)
     | Abstract (s,_) ->
 	Format.fprintf ppf "<abstract=%s>" s
     | Absent -> 	
@@ -423,8 +428,12 @@ let rec compare x y =
 	  raise (CDuceExn (string_latin1 "comparing functional values"))
       | Abstract (s1,v1), Abstract (s2,v2) ->
 	  let c = Types.Abstract.T.compare s1 s2 in if c <> 0 then c 
-	  else Pervasives.compare (Obj.magic v1 : float) (Obj.magic v2 : float)
-	    (* raise (CDuceExn (string_latin1 "comparing abstract values")) *)
+	  else begin
+              match s1 with
+              |"float" -> Pervasives.compare (Obj.magic v1 : float) (Obj.magic v2 : float)
+              |"cdata" -> Pervasives.compare (Obj.magic v1 : Encodings.Utf8.t) (Obj.magic v2 : Encodings.Utf8.t)
+              |_ -> raise (CDuceExn (string_latin1 "comparing abstract values"))
+          end
       | Absent,_ | _,Absent ->
 	  Format.fprintf Format.std_formatter
 	    "ERR: Compare %a %a@." print x print y;
@@ -719,6 +728,9 @@ let print_utf8 v =
 let float n =
   Abstract ("float", Obj.repr n)
 
+let cdata n =
+  Abstract ("cdata", Obj.repr n)
+
 let cduce2ocaml_option f v =
   match normalize v with
     | Pair (x,y) -> Some (f x)
