@@ -122,6 +122,12 @@ let exn_namespaces = lazy (
       Value.string_latin1 "namespaces"))
 )
 
+let exn_cdata_of = lazy (
+  Value.CDuceExn (
+    Value.Pair (
+      Value.Atom (Atoms.V.mk_ascii "Invalid_argument"),
+      Value.string_latin1 "cdata_of"))
+)
 
 let eval_load_file ~utf8 e =
   Cduce_loc.protect_op "load_file";
@@ -445,3 +451,11 @@ register_fun "float_of" string float
      let (s,_) = Value.get_string_utf8 v in
      try Value.float (float_of_string (U.get_str s))
      with Failure _ -> raise (Lazy.force exn_float_of));;
+
+(* cdata *)
+
+register_fun "cdata_of" string string
+  (fun v ->
+     let (s,_) = Value.get_string_utf8 v in
+     try Value.cdata (U.get_str s)
+     with Failure _ -> raise (Lazy.force exn_cdata_of));;
