@@ -1,15 +1,15 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 type ext_info
 
 val get: unit -> ext_info option
 
-val register: ref (bool -> string -> Types.Node.t list -> (int * Types.t))
-val ext_info: ref (unit -> ext_info)
+val register: (bool -> string -> Types.Node.t list -> (int * Types.t)) ref
+val ext_info: (unit -> ext_info) ref
 
 val resolve: string -> Types.Node.t list -> (int * Types.t)
 val typ: string -> Types.Node.t list -> Types.t
