@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  The CDuce compiler                                                    *)
 (*  Alain Frisch <Alain.Frisch@inria.fr> and the CDuce team               *)
-(*  Copyright CNRS,INRIA, 2003,2004,2005,2006 (see LICENSE for details)   *)
+(*  Copyright CNRS,INRIA, 2003,2004,2005,2006,2007 (see LICENSE for details)  *)
 (**************************************************************************)
 
 (* Typed abstract syntax *) 
@@ -15,7 +15,7 @@
     values than can result from the expression or flow to the branch
 *)
 
-open Location
+open Cduce_loc
 open Ident
 
 type tpat = Patterns.node
